#ifndef LSVPD_ADAPTER_H
#define LSVPD_ADAPTER_H

/*
  adapter - General functions for dealing with adapters.
  
  This file is part of the Linux lsvpd package.
  
  (C) Copyright IBM Corp. 2006
  
  Maintained by  Martin Schwenke <martins@au.ibm.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
 
  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
  $Id: adapter.h,v 1.1.1.1 2013/09/12 09:32:49 bpeters Exp $
*/

#include "node.h"
  
extern const char *
adapter_get_os_subdir(char * bus_info);

extern char *
adapter_get_yl(const char * adapter_bus_dir);

/********************************************************************/

#define ADAPTER_TYPE_DEFAULT       "adapter"

#define ADAPTER_TYPE_PSEUDO        "pseudo"
#define ADAPTER_TYPE_VIO           "vio"
#define ADAPTER_TYPE_ISA           "isa"
#define ADAPTER_TYPE_UNKNOWN       BUS_TYPE_UNKNOWN

#define ADAPTER_SUBTYPE_SCSI       "scsi"
#define ADAPTER_SUBTYPE_ETHERNET   "ethernet"
#define ADAPTER_SUBTYPE_IDE        "ide"
#define ADAPTER_SUBTYPE_USB        "usb"
#define ADAPTER_SUBTYPE_DISPLAY    "display"
#define ADAPTER_SUBTYPE_SERIAL     "serial"
#define ADAPTER_SUBTYPE_SOUND      "sound"
#define ADAPTER_SUBTYPE_FIBRE      "fibre"
#define ADAPTER_SUBTYPE_RAID       "raid"
#define ADAPTER_SUBTYPE_SATA       "sata"
#define ADAPTER_SUBTYPE_ATA        "ata"
#define ADAPTER_SUBTYPE_ISCSI      "iscsi"
#define ADAPTER_SUBTYPE_SCSI_DEBUG "scsi_debug"
#define ADAPTER_SUBTYPE_IBMVETH    "ibmveth"
#define ADAPTER_SUBTYPE_IBMVSCSI   "ibmvscsi"
#define ADAPTER_SUBTYPE_OMS        "oms"
#define ADAPTER_SUBTYPE_TOKEN      "token"
#define ADAPTER_SUBTYPE_GENPCI     "genpci"

/********************************************************************/

typedef char *
adapter_get_ds_function_t(const node_t type,
			  const bus_addr_t bus_addr,
			  const node_t subtype);

extern adapter_get_ds_function_t * adapter_get_ds_function;

extern adapter_get_ds_function_t adapter_get_ds;

/********************************************************************/

extern char *
adapter_get_source_node(const node_t bus_type,
			const bus_addr_t bus_addr,
			const node_t subtype);

typedef node_t
adapter_get_subtype_function_t(const node_t type,
			       const bus_addr_t bus_addr);

extern adapter_get_subtype_function_t * adapter_get_subtype_function;

extern adapter_get_subtype_function_t adapter_get_subtype;

#endif
