/*
  device - VPD support routines for devices.
  
  This file is part of the Linux lsvpd package.
  
  (C) Copyright IBM Corp. 2005, 2006
  
  Maintained by  Martin Schwenke <martins@au.ibm.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
 
  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
  $Id: device.c,v 1.1.1.1 2013/09/12 09:32:49 bpeters Exp $
*/

/* For asprintf(3). */
#define _GNU_SOURCE

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/param.h>
#include <sys/sysmacros.h>

//#include "util.h"

#include "lsvpd.h"
#include "init.h"

#include "device.h"

/********************************************************************/

void
device_close_temporary(device_temp_t ** d)
{
	if (NULL != *d) {
		if (-1 != (*d)->fd)
			close((*d)->fd);
		if (NULL != (*d)->name) {
			unlink((*d)->name);
			free((*d)->name);
		}
		free(*d);
	}
	*d = NULL;
}

extern device_temp_t *
device_open_temporary(const device_node_info_t * info)
{
	device_temp_t * ret;

	if (NULL != (ret = malloc(sizeof(device_temp_t)))) {
		ret->fd = -1;
		if (-1 != asprintf(&ret->name, "%s/node-%u-%u-%u",
				   lsvpd_db_temp_dir,
				   (unsigned int) info->mode,
				   info->major, info->minor))
			if (0 == mknod(ret->name, 
				       0660 | info->mode,
				       makedev(info->major, info->minor))) {
				ret->fd = open(ret->name, O_RDONLY|O_NONBLOCK);
				if (-1 == ret->fd)
					device_close_temporary(&ret);
			} else
				device_close_temporary(&ret);
		else
			device_close_temporary(&ret);
	}
	return ret;
}

/********************************************************************/

static void
init(void)
{
	node_functions_t i = 
		{
			.type      = DEVICE_TYPE_DEFAULT,
			.supertype = NODE_TYPE_DEFAULT,
		};
	node_type_register(&i);
}

INIT(init);
